<a id="mypy-boto3-backup"></a>

# mypy-boto3-backup

[![PyPI - types-aiobotocore-backup](https://img.shields.io/pypi/v/types-aiobotocore-backup.svg?color=blue)](https://pypi.org/project/types-aiobotocore-backup)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-backup.svg?color=blue)](https://pypi.org/project/types-aiobotocore-backup)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-backup?color=blue)](https://pypistats.org/packages/types-aiobotocore-backup)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.Backup 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/backup.html#Backup)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-backup docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_backup/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-backup](#mypy-boto3-backup)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `Backup`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `Backup` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[backup]'

# Lite version does not provide session.create_client overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[backup]'

# standalone installation
python -m pip install types-aiobotocore-backup
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[backup]` in your environment:
  `python -m pip install 'types-aiobotocore[backup]'`

Both type checking and auto-complete should work for `Backup` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[backup]` in your environment:
  `python -m pip install 'types-aiobotocore[backup]'`

Both type checking and auto-complete should work for `Backup` service. No
explicit type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[backup]` in your environment:
  `python -m pip install 'types-aiobotocore[backup]'`
- Run `mypy` as usual

Type checking should work for `Backup` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[backup]` in your environment:
  `python -m pip install 'types-aiobotocore[backup]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Backup` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`BackupClient` provides annotations for `session.create_client("backup")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_backup import BackupClient

session = get_session()
async with session.create_client("backup") as client:
    client: BackupClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="literals"></a>

### Literals

`types_aiobotocore_backup.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from types_aiobotocore_backup.literals import (
    BackupJobStateType,
    BackupVaultEventType,
    ConditionTypeType,
    CopyJobStateType,
    RecoveryPointStatusType,
    RestoreJobStatusType,
    StorageClassType,
    ServiceName,
)

def check_value(value: BackupJobStateType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_backup.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_backup.type_defs import (
    AdvancedBackupSettingTypeDef,
    BackupJobTypeDef,
    BackupPlanInputTypeDef,
    BackupPlanTemplatesListMemberTypeDef,
    BackupPlanTypeDef,
    BackupPlansListMemberTypeDef,
    BackupRuleInputTypeDef,
    BackupRuleTypeDef,
    BackupSelectionTypeDef,
    BackupSelectionsListMemberTypeDef,
    BackupVaultListMemberTypeDef,
    CalculatedLifecycleTypeDef,
    ConditionParameterTypeDef,
    ConditionTypeDef,
    ConditionsTypeDef,
    ControlInputParameterTypeDef,
    ControlScopeTypeDef,
    CopyActionTypeDef,
    CopyJobTypeDef,
    CreateBackupPlanInputRequestTypeDef,
    CreateBackupPlanOutputTypeDef,
    CreateBackupSelectionInputRequestTypeDef,
    CreateBackupSelectionOutputTypeDef,
    CreateBackupVaultInputRequestTypeDef,
    CreateBackupVaultOutputTypeDef,
    CreateFrameworkInputRequestTypeDef,
    CreateFrameworkOutputTypeDef,
    CreateReportPlanInputRequestTypeDef,
    CreateReportPlanOutputTypeDef,
    DeleteBackupPlanInputRequestTypeDef,
    DeleteBackupPlanOutputTypeDef,
    DeleteBackupSelectionInputRequestTypeDef,
    DeleteBackupVaultAccessPolicyInputRequestTypeDef,
    DeleteBackupVaultInputRequestTypeDef,
    DeleteBackupVaultLockConfigurationInputRequestTypeDef,
    DeleteBackupVaultNotificationsInputRequestTypeDef,
    DeleteFrameworkInputRequestTypeDef,
    DeleteRecoveryPointInputRequestTypeDef,
    DeleteReportPlanInputRequestTypeDef,
    DescribeBackupJobInputRequestTypeDef,
    DescribeBackupJobOutputTypeDef,
    DescribeBackupVaultInputRequestTypeDef,
    DescribeBackupVaultOutputTypeDef,
    DescribeCopyJobInputRequestTypeDef,
    DescribeCopyJobOutputTypeDef,
    DescribeFrameworkInputRequestTypeDef,
    DescribeFrameworkOutputTypeDef,
    DescribeGlobalSettingsOutputTypeDef,
    DescribeProtectedResourceInputRequestTypeDef,
    DescribeProtectedResourceOutputTypeDef,
    DescribeRecoveryPointInputRequestTypeDef,
    DescribeRecoveryPointOutputTypeDef,
    DescribeRegionSettingsOutputTypeDef,
    DescribeReportJobInputRequestTypeDef,
    DescribeReportJobOutputTypeDef,
    DescribeReportPlanInputRequestTypeDef,
    DescribeReportPlanOutputTypeDef,
    DescribeRestoreJobInputRequestTypeDef,
    DescribeRestoreJobOutputTypeDef,
    DisassociateRecoveryPointInputRequestTypeDef,
    ExportBackupPlanTemplateInputRequestTypeDef,
    ExportBackupPlanTemplateOutputTypeDef,
    FrameworkControlTypeDef,
    FrameworkTypeDef,
    GetBackupPlanFromJSONInputRequestTypeDef,
    GetBackupPlanFromJSONOutputTypeDef,
    GetBackupPlanFromTemplateInputRequestTypeDef,
    GetBackupPlanFromTemplateOutputTypeDef,
    GetBackupPlanInputRequestTypeDef,
    GetBackupPlanOutputTypeDef,
    GetBackupSelectionInputRequestTypeDef,
    GetBackupSelectionOutputTypeDef,
    GetBackupVaultAccessPolicyInputRequestTypeDef,
    GetBackupVaultAccessPolicyOutputTypeDef,
    GetBackupVaultNotificationsInputRequestTypeDef,
    GetBackupVaultNotificationsOutputTypeDef,
    GetRecoveryPointRestoreMetadataInputRequestTypeDef,
    GetRecoveryPointRestoreMetadataOutputTypeDef,
    GetSupportedResourceTypesOutputTypeDef,
    LifecycleTypeDef,
    ListBackupJobsInputRequestTypeDef,
    ListBackupJobsOutputTypeDef,
    ListBackupPlanTemplatesInputRequestTypeDef,
    ListBackupPlanTemplatesOutputTypeDef,
    ListBackupPlanVersionsInputRequestTypeDef,
    ListBackupPlanVersionsOutputTypeDef,
    ListBackupPlansInputRequestTypeDef,
    ListBackupPlansOutputTypeDef,
    ListBackupSelectionsInputRequestTypeDef,
    ListBackupSelectionsOutputTypeDef,
    ListBackupVaultsInputRequestTypeDef,
    ListBackupVaultsOutputTypeDef,
    ListCopyJobsInputRequestTypeDef,
    ListCopyJobsOutputTypeDef,
    ListFrameworksInputRequestTypeDef,
    ListFrameworksOutputTypeDef,
    ListProtectedResourcesInputRequestTypeDef,
    ListProtectedResourcesOutputTypeDef,
    ListRecoveryPointsByBackupVaultInputRequestTypeDef,
    ListRecoveryPointsByBackupVaultOutputTypeDef,
    ListRecoveryPointsByResourceInputRequestTypeDef,
    ListRecoveryPointsByResourceOutputTypeDef,
    ListReportJobsInputRequestTypeDef,
    ListReportJobsOutputTypeDef,
    ListReportPlansInputRequestTypeDef,
    ListReportPlansOutputTypeDef,
    ListRestoreJobsInputRequestTypeDef,
    ListRestoreJobsOutputTypeDef,
    ListTagsInputRequestTypeDef,
    ListTagsOutputTypeDef,
    ProtectedResourceTypeDef,
    PutBackupVaultAccessPolicyInputRequestTypeDef,
    PutBackupVaultLockConfigurationInputRequestTypeDef,
    PutBackupVaultNotificationsInputRequestTypeDef,
    RecoveryPointByBackupVaultTypeDef,
    RecoveryPointByResourceTypeDef,
    RecoveryPointCreatorTypeDef,
    ReportDeliveryChannelTypeDef,
    ReportDestinationTypeDef,
    ReportJobTypeDef,
    ReportPlanTypeDef,
    ReportSettingTypeDef,
    ResponseMetadataTypeDef,
    RestoreJobsListMemberTypeDef,
    StartBackupJobInputRequestTypeDef,
    StartBackupJobOutputTypeDef,
    StartCopyJobInputRequestTypeDef,
    StartCopyJobOutputTypeDef,
    StartReportJobInputRequestTypeDef,
    StartReportJobOutputTypeDef,
    StartRestoreJobInputRequestTypeDef,
    StartRestoreJobOutputTypeDef,
    StopBackupJobInputRequestTypeDef,
    TagResourceInputRequestTypeDef,
    UntagResourceInputRequestTypeDef,
    UpdateBackupPlanInputRequestTypeDef,
    UpdateBackupPlanOutputTypeDef,
    UpdateFrameworkInputRequestTypeDef,
    UpdateFrameworkOutputTypeDef,
    UpdateGlobalSettingsInputRequestTypeDef,
    UpdateRecoveryPointLifecycleInputRequestTypeDef,
    UpdateRecoveryPointLifecycleOutputTypeDef,
    UpdateRegionSettingsInputRequestTypeDef,
    UpdateReportPlanInputRequestTypeDef,
    UpdateReportPlanOutputTypeDef,
)

def get_structure() -> AdvancedBackupSettingTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`types-aiobotocore-backup` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[types-aiobotocore-backup docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_backup/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
